@@ -1,5 +1,13 @@
 class CoxbuildException(Exception):
+    """Common base exception for all coxbuild exceptions."""
+
     def __init__(self, message: str, cause: Exception | None = None) -> None:
+        """
+        Create CoxbuildException.
+
+        message: exception mesage
+        cause: inner exception
+        """
         super().__init__()
         self.message = message
         self.cause = cause
